/***************************************************************************//**
*   @file   ad5272.c
*   @brief  Header file of AD5272 Driver for Microblaze processor.
*   @author DBogdan (dragos.bogdan@analog.com)
*
********************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
* LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
* SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
* CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
********************************************************************************
*   SVN Revision: 468
*******************************************************************************/
#ifndef _AD5272_H_
#define _AD5272_H_
#ifdef AD5272_GLOBALS
	#define AD5272_EXT extern volatile
#else
	#define AD5272_EXT volatile
#endif

/*****************************************************************************/
/* Include Files                                                             */
/*****************************************************************************/
#include "xil_types.h"
#include "xparameters.h"

/*****************************************************************************/
/* Types Declarations                                                        */
/*****************************************************************************/
typedef union _uCProbeDataUnion
{
	char 			chData;
	unsigned char 	uchData;
	short			siData;
	unsigned short	usiData;
	int 			iData;
	unsigned int 	uiData;
	float 			fData;
}uCProbeDataUnion;

/******************************************************************************/
/* AD5272                                                                     */
/******************************************************************************/

/* AD5272 Address */
#define AD5272_ADDRESS				0x2F	// ADDR = GND.

/* AD5272 Commands */
#define AD5272_NOP					0x00
#define AD5272_WRITE_RDAC			0x01
#define AD5272_READ_RDAC			0x02
#define AD5272_STORE_RDAC_50TP		0x03
#define AD5272_RESET				0x04
#define AD5272_READ_CONTENT_50TP	0x05
#define AD5272_READ_ADDRESS_50TP	0x06
#define AD5272_WRITE_CONTROL		0x07
#define AD5272_READ_CONTROL			0x08
#define AD5272_SHUTDOWN				0x09

/* AD5272 Control Register Bits */
#define AD5272_C3					(1 << 3)
#define AD5272_C2					(1 << 2)
#define AD5272_C1					(1 << 1)
#define AD5272_C0					(1 << 0)

/******************************************************************************/
/* GPIO                                                                       */
/******************************************************************************/
#define AD5272_RESET_PIN	(1<<1)

/******************************************************************************/
/* Monitored variables declarations                                           */
/******************************************************************************/
AD5272_EXT uCProbeDataUnion AD5272_data[15];	// Used to store the values for uC-Probe communication.

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/
int AD5272_Init(void); 							// Initializes the communication with the device.
int AD5272_UpdateParameters(void); 				// Updates the device's monitored and controlled parameters.
#endif /* AD5272_H_ */
